@@ -1,7 +1,9 @@
 '''Hypertrace wrapper around OTel GRPC instrumentor'''
+import json
 import logging
 import traceback
 import grpc
+from google.protobuf.json_format import MessageToDict
 from opentelemetry import trace
 from opentelemetry.instrumentation.grpc import (
     GrpcInstrumentorServer,
@@ -13,7 +15,7 @@ from opentelemetry.instrumentation.grpc.version import __version__
 from opentelemetry.instrumentation.grpc.grpcext import intercept_channel
 from wrapt import wrap_function_wrapper as _wrap # pylint: disable=R0801
 from hypertrace.agent import constants
-from hypertrace.agent.filter.registry import Registry
+from hypertrace.agent.filter.registry import Registry, TYPE_RPC
 from hypertrace.agent.instrumentation import BaseInstrumentorWrapper
 
 # Initialize logger with local module name
@@ -172,14 +174,15 @@ class OpenTelemetryServerInterceptorWrapper(_server.OpenTelemetryServerIntercept
                 span = context._active_span # pylint: disable=W0212
 
                 invocation_metadata = dict(handler_call_details.invocation_metadata)
-
+                req_dict = MessageToDict(request_or_iterator)
                 self._gisw.generic_rpc_request_handler(
-                    invocation_metadata, request_or_iterator, span)
+                    invocation_metadata, json.dumps(req_dict), span)
                 try:
                     block_result = Registry().apply_filters(span,
                                                             '',
                                                             invocation_metadata,
-                                                            request_or_iterator)
+                                                            request_or_iterator,
+                                                            TYPE_RPC)
                     if block_result:
                         logger.debug('should block evaluated to true, aborting with 403')
                         return context.abort(grpc.StatusCode.PERMISSION_DENIED, 'Permission Denied')
@@ -191,8 +194,12 @@ class OpenTelemetryServerInterceptorWrapper(_server.OpenTelemetryServerIntercept
                     trailing_metadata = context.get_trailing_metadata()
                     if len(trailing_metadata) > 0:
                         trailing_metadata = dict(trailing_metadata[0])
-                        self._gisw.generic_rpc_response_handler(
-                            trailing_metadata, response, span)
+                    else:
+                        trailing_metadata = {}
+
+                    response_dict = MessageToDict(response)
+                    self._gisw.generic_rpc_response_handler(
+                        trailing_metadata, json.dumps(response_dict), span)
 
                     return response
                 except Exception as error: # pylint: disable=W0703
